@@ -44,16 +44,16 @@ import sys
 from functools import lru_cache
 from itertools import cycle
 from types import ModuleType
-from typing import IO, Iterable, Iterator, List, Optional, Sequence, Union
+from typing import IO, Any, Iterable, Iterator, List, Optional, Sequence, Union
 
 # 3rd party
 import click
 import deprecation_alias
-from domdf_python_tools.import_tools import discover, discover_entry_points
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.words import SANS_SERIF_ITALIC_LETTERS
 from mistletoe import block_token, span_token  # type: ignore
 from mistletoe.base_renderer import BaseRenderer  # type: ignore
+from typing_extensions import TypeGuard
 
 # this package
 from consolekit import terminal_colours, tracebacks
@@ -79,7 +79,7 @@ __all__ = [
 _deprecator = deprecation_alias.deprecated(
 		deprecated_in="1.0.0",
 		removed_in="2.0.0",
-		current_version="1.2.2",
+		current_version="1.4.0",
 		details="Import from consolekit.tracebacks instead."
 		)
 
@@ -91,7 +91,7 @@ def get_env_vars(ctx, args, incomplete):  # noqa: D103
 	return [k for k in os.environ.keys() if incomplete in k]
 
 
-def is_command(obj) -> bool:
+def is_command(obj: Any) -> TypeGuard[click.Command]:
 	"""
 	Return whether ``obj`` is a click command.
 
@@ -116,6 +116,9 @@ def import_commands(source: Optional[ModuleType] = None, entry_point: Optional[s
 	:param entry_point:
 	"""
 
+	# 3rd party
+	from domdf_python_tools.import_tools import discover, discover_entry_points
+
 	all_commands = []
 
 	if source is not None:
@@ -142,16 +145,22 @@ def abort(message: str, colour: ColourTrilean = None) -> Exception:
 	return click.Abort()
 
 
-def overtype(*objects, sep: str = ' ', end: str = '', file: IO = None, flush: bool = False) -> None:
-	"""
-	Print ``objects`` to the text stream ``file``, starting with ``"\\r"``, separated by ``sep``
+def overtype(
+		*objects,
+		sep: str = ' ',
+		end: str = '',
+		file: Optional[IO] = None,
+		flush: bool = False,
+		) -> None:
+	r"""
+	Print ``objects`` to the text stream ``file``, starting with ``"\r"``, separated by ``sep``
 	and followed by ``end``.
 
 	``sep``, ``end``, ``file`` and ``flush``, if present, must be given as keyword arguments
 
 	All non-keyword arguments are converted to strings like :class:`str` does and written to the stream,
 	separated by `sep` and followed by `end`.
-	If no such arguments are given, :func:`~consolekit.utils.overtype` will just write ``"\\r"``.
+	If no such arguments are given, :func:`~consolekit.utils.overtype` will just write ``"\r"``.
 
 	.. TODO:: This does not currently work in the PyCharm console, at least on Windows
 
@@ -161,7 +170,7 @@ def overtype(*objects, sep: str = ' ', end: str = '', file: IO = None, flush: bo
 	:param file: An object with a ``write(string)`` method.
 	:default file: ``sys.stdout``
 	:param flush: If :py:obj:`True`, the stream is forcibly flushed.
-	"""  # noqa D400
+	"""  # noqa: D400
 
 	object0 = f"\r{objects[0]}"
 	objects = (object0, *objects[1:])
@@ -202,9 +211,8 @@ def coloured_diff(
 	The modification times are normally expressed in the ISO 8601 format.
 
 	.. versionadded:: 0.3.0
-	.. latex:clearpage::
 
-	**Example:**
+	:bold-title:`Example:`
 
 	>>> for line in coloured_diff(
 	...     'one two three four'.split(),
@@ -323,11 +331,6 @@ def hidden_cursor() -> Iterator:
 		show_cursor()
 
 
-@lru_cache(1)
-def _pycharm_hosted():
-	return os.environ.get("PYCHARM_HOSTED", 0)
-
-
 @lru_cache(1)
 def _pycharm_terminal():
 	try:
@@ -376,7 +379,7 @@ class TerminalRenderer(BaseRenderer):
 		:param token: The token to render.
 		"""
 
-		if _pycharm_hosted():
+		if int(os.environ.get("PYCHARM_HOSTED", 0)):
 			# Pycharm terminal doesn't support italic escape
 			return SANS_SERIF_ITALIC_LETTERS(self.render_inner(token))
 
@@ -403,7 +406,7 @@ class TerminalRenderer(BaseRenderer):
 		:param token: The token to render.
 		"""
 
-		if _pycharm_hosted() or _pycharm_terminal():
+		if int(os.environ.get("PYCHARM_HOSTED", 0)) or _pycharm_terminal():
 			# Pycharm terminal doesn't support strikethrough
 			return self.render_inner(token)
 
@@ -448,6 +451,16 @@ class TerminalRenderer(BaseRenderer):
 		else:
 			return f" * {self.render_inner(token).lstrip()}"
 
+	@staticmethod
+	def render_line_break(token):
+		"""
+		Render a line break in a multiline paragraph.
+
+		:param token:
+		"""
+
+		return ' '
+
 	def render(self, token) -> str:
 		"""
 		Render the given token for display in a terminal.
@@ -476,6 +489,7 @@ def long_echo(
 	:no-default colour:
 
 	.. tip:: Allow the user to control the value of ``use_pager`` with the :func:`no_pager_option` decorator.
+	.. latex:clearpage::
 	"""
 
 	if isinstance(text, str):
